@@ -1,4 +1,4 @@
-package Sub::Name; # git description: v0.22-4-gd2ca7a1
+package Sub::Name; # git description: v0.23-9-g652bff5
 # ABSTRACT: (Re)name a sub
 # KEYWORDS: subroutine function utility name rename symbol
 
@@ -54,7 +54,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.23'; # TRIAL
+our $VERSION = '0.24'; # TRIAL
 
 use Exporter ();
 *import = \&Exporter::import;
@@ -82,7 +82,7 @@ Sub::Name - (Re)name a sub
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -141,7 +141,7 @@ Matthijs van Duin <xmath@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leon Timmermans Graham Knop Reini Urban Florian Ragwitz Matthijs van Duin Dagfinn Ilmari Mannsåker gfx Aristotle Pagaltzis J.R. Mash Alexander Bluhm
+=for stopwords Karen Etheridge Graham Knop Leon Timmermans Reini Urban Florian Ragwitz Matthijs van Duin Dagfinn Ilmari Mannsåker gfx Aristotle Pagaltzis J.R. Mash Alexander Bluhm
 
 =over 4
 
@@ -151,11 +151,11 @@ Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Leon Timmermans <fawaka@gmail.com>
+Graham Knop <haarg@haarg.org>
 
 =item *
 
-Graham Knop <haarg@haarg.org>
+Leon Timmermans <fawaka@gmail.com>
 
 =item *
 
